TRAPR.DataVisualization <- function(Data, type_of_plot,logged = TRUE)
{
	cat('Visualization for Data$CurrentMatrix\n')
	library(gridExtra)
	cat('Loading gridExtra package \n')
	library(ggplot2)
	cat('Loading ggplot2 package \n')
	library(reshape2)
	cat('Loading reshape2 package \n')
	
	if (type_of_plot != 'box' && type_of_plot != 'MA'&& type_of_plot != 'MV' && type_of_plot != 'SE'&& type_of_plot != 'DS'&& type_of_plot != 'ALL')
	stop('err please check plot names !!!! \n')
	
	Data <- TRAPR.Filter.ZeroValue(Data)
	TestMatrix <- Data$CurrentMatrix
	rownames(TestMatrix) <- Data$CurrentGene
	colnames(TestMatrix) <- Data$CurrentSample
	sample_level = Data$Tag
	
	#'Mean' and 'Variance'
	TestMatrix.mean <- (apply(TestMatrix, 1, mean))
	TestMatrix.var <- (apply(TestMatrix, 1, var))
	Mean = TestMatrix.mean
	Variance = TestMatrix.var
		
	#'MA'
	Exp1.Mean <- apply(TestMatrix[ ,Data$Exp1], 1, mean)
	Exp2.Mean <- apply(TestMatrix[ ,Data$Exp2], 1, mean)
	
	
	#Scatter plot for Exp1 vs Exp2
	Exp1.Mean <- apply(TestMatrix[ ,Data$Exp1], 1, mean)
	Exp2.Mean <- apply(TestMatrix[ ,Data$Exp2], 1, mean)
	
	##################################### plot functions########################################

	Boxplot.data <- function()
	{
		tt = melt(TestMatrix)
		group = c( rep(sample_level[1], length(Data$Exp1)*dim(TestMatrix )[1]), rep(sample_level[2], length(Data$Exp2) * dim(TestMatrix)[1]) )
		Data_value = data.frame(tt,group)
		colnames(Data_value) =c("gene","sample","value","category")
		return(Data_value)
	}
	Boxplot <- function(input_data)
	{	
		p = ggplot(input_data, aes(sample, value))
		p = p + geom_boxplot(aes(fill=category ,colour=category ))
		p = p + stat_summary(fun.y=median, geom="crossbar", ymin=-1, ymax=1, color="grey90")
		p = p + labs(x = "sample", y = "RPKM")
		p = p + theme(plot.margin = unit(c(0,0,1,0), "cm"))
		p = p + labs(title="boxplot")
		return(p)
	}
	
	MA <- function(M,A)
	{
		MA_TestDataframe <- data.frame(M,A)
		p = ggplot(MA_TestDataframe, aes(A, M)) 
		p = p + geom_point(shape=8, colour = "#FF3399")
		#p = p + geom_hline(aes(yintercept=0),colour = "#6633CC",size = 1)
		p = p + labs(title="MA plot for Exp1 vs Exp2")
		p = p + geom_smooth(method="loess")
		return(p)
	}
	
	Mean_Variance.data <- function()
	{
		MV_TestDataframe <- data.frame(Mean,Variance )
		return(MV_TestDataframe)
	}
	
	Mean_Variance <- function(input_data)
	{
		p = ggplot(input_data, aes(Mean, Variance)) 
		p = p + geom_point(shape=8, colour = "#FFFF00")
		p = p +  geom_smooth(method=lm,colour="#66FF00") + scale_colour_hue(l=50)
		p = p + labs(title="Mean vs Variance")
		return(p)

	}
	
	Scatter_plot_Exp1_Exp2.data <- function()
	{
		SE_TestDataframe <- data.frame(Exp1.Mean,Exp2.Mean )
		return(SE_TestDataframe)
	}
	
	Scatter_plot_Exp1_Exp2 <- function(input_data)
	{
		p = ggplot(input_data, aes(Exp1.Mean, Exp2.Mean)) 
		p = p + geom_point(shape=8, colour = "#0000FF")
		#p = p + geom_smooth(method = lm, colour = "#FF33CC",fullrange=T,size = 1)
		p = p + geom_smooth(method="loess", colour = "#FF33CC",fullrange=T,size = 1)
		#plot(p)
		p = p + labs(title="Scatter plot for Exp1 vs Exp2")
		return(p)
	}
	
	Density_plot.data <- function()
	{
		DS_TestDataframe <- data.frame(TestMatrix)
		m.d = melt(DS_TestDataframe)
		return(m.d)
		#### before Normalization ####
		#a = data.frame(sample$CurrentMatrix)
		#b = melt(a)
		#ggplot(b, aes(value, colour = variable)) +  geom_density()
	}
	
	Density_plot <- function(input_data,les)
	{
		p = ggplot(input_data, aes(value, colour = variable)) 
		p = p + geom_density(size=0.5)
		p = p + labs(legend.key.size = unit(les, "cm"))
		p = p + labs(title="Density Plot")
		return(p)

	}
	#####################################################################################
	##################################### boxplot ########################################
	if(type_of_plot == 'box') 
		{
		if (logged) 
			{
				in_data = Boxplot.data()
				plot(Boxplot(in_data))				
			}
		else
			{
				in_data = Boxplot.data()
				in_data$value = log2(in_data$value)
				plot(Boxplot(in_data))
			}
		}
	#################################################################################
	##################################### MA ########################################
	
	if(type_of_plot == 'MA') 
		{
		if (logged)
			{
			#'MA'
				M <- Exp1.Mean - Exp2.Mean
				A <- (Exp1.Mean + Exp2.Mean)/2
				plot(MA(M,A))
			}
		else
			{
				#'MA'
				ExpIndex <- intersect(which(Exp1.Mean > 0), which(Exp2.Mean > 0))
				M <- log2(Exp1.Mean[ExpIndex]) - log2(Exp2.Mean[ExpIndex])
				A <- log2(Exp1.Mean[ExpIndex]) + log2(Exp2.Mean[ExpIndex])
				plot(MA(M,A))
			}
			
		}
	##################################################################################################
	##################################### Mean' and 'Variance ########################################
if(type_of_plot == 'MV') 
		{
		if (logged)
			{							
				in_data = Mean_Variance.data()
				#print(head(in_data))
				plot(Mean_Variance(in_data)) 
			}
		
		else
			{
				in_data = log2(Mean_Variance.data())
				plot(Mean_Variance(in_data)) 
			}
		}

	##################################################################################################
	##################################### Scatter plot for Exp1 vs Exp2 ##############################
if(type_of_plot == 'SE') 
		{
		if (logged)
			{							
				in_data = Scatter_plot_Exp1_Exp2.data()
				plot(Scatter_plot_Exp1_Exp2(in_data)) 
			}
		
		else
			{
				in_data = log2(Scatter_plot_Exp1_Exp2.data())
				plot(Scatter_plot_Exp1_Exp2(in_data))
			}
		}	
	##################################################################################################
	##################################### density plot ##############################
if(type_of_plot == 'DS') 
		{
		if (logged)
			{							
				in_data = Density_plot.data()
				plot(Density_plot(in_data,0.6))	
			}		
		else
			{
				in_data = Density_plot.data()
				in_data$value = log2(in_data$value)
				plot(Density_plot(in_data,0.6))
			}
		}		
	##################################################################################################
	##################################### ALL ########################################################
	if(type_of_plot == 'ALL') 
		{
			if (logged)
			{
				box_in_data = Boxplot.data()
				
				M <- Exp1.Mean - Exp2.Mean
				A <- (Exp1.Mean + Exp2.Mean)/2
				
				MV_in_data = Mean_Variance.data()
				
				SE_in_data = Scatter_plot_Exp1_Exp2.data()
	
				DS_in_data = Density_plot.data()
				
				grid.arrange(MA(M,A),Mean_Variance(MV_in_data),Scatter_plot_Exp1_Exp2(SE_in_data),Density_plot(DS_in_data,0.3),Boxplot(box_in_data),ncol=3)
				#ggsave(p, file="Genre_04_04.PNG", width=10, height=10)
		}
	else 
		{
				box_in_data = Boxplot.data()
				box_in_data$value = log2(box_in_data$value)
				
				ExpIndex <- intersect(which(Exp1.Mean > 0), which(Exp2.Mean > 0))
				M <- log2(Exp1.Mean[ExpIndex]) - log2(Exp2.Mean[ExpIndex])
				A <- log2(Exp1.Mean[ExpIndex]) + log2(Exp2.Mean[ExpIndex])
				
				MV_in_data = log2(Mean_Variance.data())

				SE_in_data = log2(Scatter_plot_Exp1_Exp2.data())
				
				DS_in_data = Density_plot.data()
				DS_in_data$value = log2(DS_in_data$value)
				
				grid.arrange( MA(M,A),Mean_Variance(MV_in_data),Scatter_plot_Exp1_Exp2(SE_in_data),Density_plot(DS_in_data,0.3),Boxplot(box_in_data),ncol=3)
				#ggsave(p, file="Genre_04_04.PNG", width=10, height=10)
		}
	}
	
}
