TRAPR.StatisticalTest <-
function(Data, Method = 'ttest', FDRControl = 'none', PvalueThre = 0.01, FCThre = 0) 
{
	cat('Statistical Analysis by', Method, 'FDR Threshould for selecting DEG is \'FDR <', as.character(PvalueThre), '\', \' Fold Change(log2(Exp1 / Exp2)) >', as.character(FCThre), '\'\n')
	Data <- TRAPR.Filter.ZeroValue(Data)
	temp <- c(1:length(Data$GeneTag))
	names(temp) <- Data$GeneTag
	FCIndex <- temp[Data$CurrentGene]

	Data$FC <- log2(apply(Data$RawMatrix[FCIndex,Data$Exp1], 1, mean) / apply(Data$RawMatrix[FCIndex,Data$Exp2], 1, mean))

	METHODS <- c('ttest', 'wilcoxon', 'edgeR', 'FC')
	Method <- pmatch(Method, METHODS)
	if (is.na(Method))
		stop('invalid statistical test method')
	if (Method == -1)
		stop('ambiguous statistical test method')
	if (Method == 1)
		Data <- TRAPR.StatisticalTest.ttest(Data)
	if (Method == 2)
		Data <- TRAPR.StatisticalTest.Wilcoxon(Data)
	if (Method == 3)
		Data <- TRAPR.StatisticalTest.EdgeR(Data)
	if (Method == 4)
		Data <- TRAPR.StatisticalTest.FC(Data)
	
	FDRMETHODS <- c('holm', 'hotchberg', 'hommel', 'bonferroni', 'BH', 'BY', 'fdr', 'none')
	Test <- pmatch(FDRControl, FDRMETHODS)
	if (is.na(Test)) stop('invalid FDR Control Method')
	if (Method < 0) stop('ambiguous FDR Control Method')
	if (Method > 0) Data$qvalues <- as.numeric(p.adjust(Data$pvalues, method = FDRControl))
	PvalIndex <- which(Data$qvalues < PvalueThre)
	FCIndex <- which(abs(Data$FC) > FCThre)
	Data$DEGIndex <- intersect(PvalIndex, FCIndex)
	cat(as.character(length(Data$DEGIndex)), ' genes selected \n')
	Data$DEGName <- Data$CurrentGene[Data$DEGIndex]
	return(Data)
}
