\name{TRAPR-package}
\alias{TRAPR-package}
\alias{TRAPR}
\docType{package}
\title{
Statistical analysis and visualization of RNA-seq data
}
\description{
High-throughput transcriptome sequencing, also known as RNA-Seq, is a standard technology for measuring gene expression at an unprecedented accuracy. Numerous Bioconductor packages have been developed for statistical analysis of RNA-Seq derived expression data. However, those tools focus on specific aspects of data analysis pipeline and lack visualization methods to confirm data integrity and process. Here, we present an R based RNA-Seq analysis pipeline, TRAPR, an integrated tool including statistical analysis and visualization of RNA-Seq expression data. TRAPR provides various functions for data management, filtering for low quality data, normalization, transformation, statistical analysis, data visualization, and result visualization that researchers can constitute customized pipeline.
}
\details{
\tabular{ll}{
Package: \tab TRAPR\cr
Type: \tab Package\cr
Version: \tab 1.0\cr
Date: \tab 2012-10-10\cr
License: \tab \cr
}

- Features\cr
TRAPR.Data : I/O functions\cr
TRAPR.Filter : Outlier Filtering\cr
TRAPR.Normalize : between sample normalization of gene expression\cr
TRAPR.Transformation : log2 or vsn transformation \cr	
TRAPR.StatisticalTest : statistical test, possibly with FDR control \cr
TRAPR.DataVisualization : 5 plots to visualize gene expression data \cr
TRAPR.ResultVisualization : 2 plots to visualize DEG result \cr


- Example\cr
Data <- TRAPR.Data.ReadExpressionTable('TRAPR_Sample.txt', sep='\t', Exp1, Exp2)\cr
Data <- TRAPR.Filter.ZeroValues(Data)	\cr
Data <- TRAPR.Normalize.UpperQuartile(Data)\cr
Data <- TRAPR.StatisticalTest(Data, Method, FDRControl, Pvalue)\cr
TRAPR.ResultVisualization(Data, 'ALL')\cr
}
}

\author{
Jae Hyun Lim, Soo Youn Lee, Ju Han Kim 

Maintainer: juhan@snu.ac.kr
}
\references{
Anders, S. and Huber, W. (2010) Differential expression analysis for sequence count data, Genome biology, 11, R106.\cr
Auer, P.L., Srivastava, S. and Doerge, R.W. (2012) Differential expression--the next generation and beyond, Briefings in functional genomics, 11, 57-62.\cr
Bullard, J.H., et al. (2010) Evaluation of statistical methods for normalization and differential expression in mRNA-Seq experiments, BMC bioinformatics, 11, 94.\cr
Calza, S., et al. (2007) Filtering genes to improve sensitivity in oligonucleotide microarray data analysis, Nucleic acids research, 35, e102.\cr
Garber, M., et al. (2011) Computational methods for transcriptome annotation and quantification using RNA-seq, Nature methods, 8, 469-477.\cr
Gentleman, R.C., et al. (2004) Bioconductor: open software development for computational biology and bioinformatics, Genome biology, 5, R80.\cr
Hardcastle, T.J. and Kelly, K.A. (2010) baySeq: empirical Bayesian methods for identifying differential expression in sequence count data, BMC bioinformatics, 11, 422.\cr
Huber, W., et al. (2002) Variance stabilization applied to microarray data calibration and to the quantification of differential expression, Bioinformatics, 18 Suppl 1, S96-104.\cr
Kadota, K., Nishiyama, T. and Shimizu, K. (2012) A normalization strategy for comparing tag count data, Algorithms for molecular biology : AMB, 7, 5.\cr
Robinson, M.D., McCarthy, D.J. and Smyth, G.K. (2010) edgeR: a Bioconductor package for differential expression analysis of digital gene expression data, Bioinformatics, 26, 139-140.\cr
Sultan, M., et al. (2008) A global view of gene activity and alternative splicing by deep sequencing of the human transcriptome, Science, 321, 956-960.\cr
Tarazona, S., et al. (2011) Differential expression in RNA-seq: a matter of depth, Genome research, 21, 2213-2223.\cr
Wang, L., et al. (2010) DEGseq: an R package for identifying differentially expressed genes from RNA-seq data, Bioinformatics, 26, 136-138.\cr
Wang, Z., Gerstein, M. and Snyder, M. (2009) RNA-Seq: a revolutionary tool for transcriptomics, Nature reviews. Genetics, 10, 57-63.\cr
}
~~ Optionally other standard keywords, one per line, from file KEYWORDS in the R documentation directory ~~
\keyword{RNA-seq, Gene expression, DEG}